com.redhat.qe.verify


checkclj

(check tval form bindings err)
source

symbolsclj

(symbols sexp)
source

used-bindingsclj

(used-bindings m form)
source

verifycljmacro

(verify x)

Evaluates expr and either logs what was evaluated, or throws an exception if it does not evaluate to logical true.

Evaluates expr and either logs what was evaluated, or throws an exception if it does not evaluate to logical true.
sourceraw docstring

verify-thatcljmacro

(verify-that x)
source

cljdoc builds & hosts documentation for Clojure/Script libraries