(verify x)Evaluates expr and either logs what was evaluated, or throws an exception if it does not evaluate to logical true.
Evaluates expr and either logs what was evaluated, or throws an exception if it does not evaluate to logical true.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |